@@ -338,12 +338,16 @@ private:
 	std::function< void( const QString& ) >& m_debug ;
 } ;
 
-class mountinfo : private QObject
+class mountinfo : public QObject
 {
 	Q_OBJECT
 public:
 	struct volumeEntry{
 
+		volumeEntry( const engines::engine& e,volumeInfo v ) :
+			engine( e ),vInfo( std::move( v ) )
+		{
+		}
 		const engines::engine& engine ;
 		volumeInfo vInfo ;
 	} ;
@@ -374,16 +378,18 @@ public:
 	void announceEvents( bool ) ;
 
 	~mountinfo() ;
-private slots:
-	void volumeUpdate( void ) ;
 private:
-	void windowsMonitor( void ) ;
-	void linuxMonitor( void ) ;
-	void qtMonitor( void ) ;
-	void updateVolume( void ) ;
-	void pbUpdate( void ) ;
+signals:
+	void updateVolume() ;
+	void pbUpdate() ;
 	void autoMount( const QString& ) ;
-	void pollForUpdates( void ) ;
+private:
+	void updateVolumeHandle() ;
+	void volumeUpdate() ;
+	void windowsMonitor() ;
+	void linuxMonitor() ;
+	void qtMonitor() ;
+	void pollForUpdates() ;
 
 	QObject * m_parent ;
 
