@@ -55,11 +55,11 @@ plugin::plugin( QWidget * parent,
 	this->setFixedSize( this->size() ) ;
 	this->setFont( parent->font() ) ;
 
-	connect( m_ui->pbSetKey,SIGNAL( clicked() ),this,SLOT( pbSetKey() ) ) ;
-	connect( m_ui->pbCancel,SIGNAL( clicked() ),this,SLOT( pbClose() ) ) ;
-	connect( m_ui->pbKeyFile,SIGNAL( clicked() ),this,SLOT( pbSelectKeyFile() ) ) ;
+	connect( m_ui->pbSetKey,&QPushButton::clicked,this,&plugin::pbSetKey ) ;
+	connect( m_ui->pbCancel,&QPushButton::clicked,this,&plugin::pbClose ) ;
+	connect( m_ui->pbKeyFile,&QPushButton::clicked,this,&plugin::pbSelectKeyFile ) ;
 
-	m_ui->pbKeyFile->setIcon( QIcon( ":/file.png" ) ) ;
+    m_ui->pbKeyFile->setIcon( QIcon( ":/icons/file.png" ) ) ;
 
 	m_ui->lineEdit->setFocus() ;
 
@@ -127,13 +127,11 @@ void plugin::pbSetKey()
 
 				return QByteArray() ;
 			}else{
-				exe = exe + " " + utility::Task::makePath( keyFile ) ;
-
 				auto env = utility::systemEnvironment() ;
 
 				env.insert( "PATH",utility::executableSearchPaths( env.value( "PATH" ) ) ) ;
 
-				return utility::Task( exe,20000,env,passphrase ).stdOut() ;
+				return utility::Task( exe,{ keyFile },20000,env,passphrase ).stdOut() ;
 			}
 		}else{
 			return QByteArray() ;
