@@ -26,6 +26,8 @@
 
 #include <fileapi.h>
 
+#include <array>
+
 class counter
 {
 public:
@@ -53,17 +55,17 @@ public:
 	result( QProcess& p ) :
 		m_exitCode( p.exitCode() ),
 		m_exitStatus( p.exitStatus() ),
-		m_stdOut( p.readAllStandardOutput() ),
-		m_stdError( p.readAllStandardError() )
+		m_stdOut( this->setOutPut( p.readAllStandardOutput() ) ),
+		m_stdErr( this->setOutPut( p.readAllStandardError() ) )
 	{
 	}
-	const QByteArray& stdOut() const
+	const QString& stdOut() const
 	{
 		return m_stdOut ;
 	}
-	const QByteArray& stdError() const
+	const QString& stdError() const
 	{
-		return m_stdError ;
+		return m_stdErr ;
 	}
 	bool success() const
 	{
@@ -75,13 +77,35 @@ public:
 	}
 	bool retry( const counter& c ) const
 	{
-		return c.Continue() && m_stdError.contains( "Named pipe connection wait failed" ) ;
+		return c.Continue() && m_stdErr.contains( "Named pipe connection wait failed" ) ;
 	}
 private:
+	bool textIsUnicode( const QByteArray& e ) const
+	{
+		if( e.size() > 2 ){
+
+			int a = e[ 0 ] ;
+			int b = e[ 1 ] ;
+
+			return a == 0 || b == 0 ;
+		}else{
+			return false ;
+		}
+	}
+	QString setOutPut( const QByteArray& e ) const
+	{
+		if( this->textIsUnicode( e ) ){
+
+			auto m = reinterpret_cast< const char16_t * >( e.constData() ) ;
+			return QString::fromUtf16( m,e.size() ) ;
+		}else{
+			return e ;
+		}
+	}
 	int m_exitCode ;
 	QProcess::ExitStatus m_exitStatus ;
-	QByteArray m_stdOut ;
-	QByteArray m_stdError ;
+	QString m_stdOut ;
+	QString m_stdErr ;
 };
 
 struct context
@@ -90,39 +114,135 @@ struct context
 	context( const context& ) = delete ;
 	context( context&& ) = delete ;
 	context( const QCoreApplication& app ) :
-		args( app.arguments() ),
-		cryptFolder( this->arg( "--cipherPath" ) ),
-		mountPoint( this->arg( "--mountPath" ) ),
-		configPath( this->arg( "--config" ) ),
-		cppcryptfsctl( this->arg( "--cppcryptfsctl-path" ) ),
-		readOnly( this->arg( "-o" ).startsWith( "ro" ) ),
-		quitCppcryptfs( this->contains( "--exit" ) )
+		m_args( app.arguments() ),
+		m_cryptFolder( this->arg( "--cipherPath" ) ),
+		m_mountPoint( this->arg( "--mountPath" ) ),
+		m_configPath( this->arg( "--config" ) ),
+		m_cppcryptfsctl( this->arg( "--cppcryptfsctl-path" ) )
 	{
 	}
 	bool contains( const QString& e ) const
 	{
-		return args.contains( e ) ;
+		return m_args.contains( e ) ;
 	}
-	QStringList args ;
-	QString cryptFolder ;
-	QString mountPoint ;
-	QString configPath ;
-	QString cppcryptfsctl ;
-	QByteArray password ;
-	bool readOnly ;
-	bool quitCppcryptfs ;
-private:
-	QString arg( const char * arg )
+	QStringList umount_opts() const
 	{
-		int j = args.size() ;
+		QStringList opts{ "-u",m_mountPoint } ;
+
+		if( this->contains( "--exit" ) ){
+
+			opts.append( "--exit" ) ;
+		}
+
+		return opts ;
+	}
+	QStringList unlocking_opts() const
+	{
+		QStringList opts{ "-p",m_password,"-d",m_mountPoint,"-m",m_cryptFolder,"-c",m_configPath } ;
+
+		if( this->arg( "-o" ).startsWith( "ro" ) ){
+
+			opts.append( "--readonly" ) ;
+		}
+
+		if( m_args.contains( "--reverse" ) ){
+
+			opts.append( "--reverse" ) ;
+		}
+
+		return opts ;
+	}
+	QStringList creating_opts() const
+	{
+		QStringList opts ;
+
+		if( m_args.contains( "--siv" ) || m_args.contains( "-S" ) ){
+
+			opts.append( "--siv" ) ;
+		}
+
+		if( m_args.contains( "--plaintext" )  || m_args.contains( "-T" ) ){
+
+			opts.append( "--plaintext" ) ;
+		}
+
+		if( m_args.contains( "--reverse" ) ){
+
+			opts.append( "--reverse" ) ;
+		}
+
+		auto m = this->arg( "V" ) ;
+
+		if( !m.isEmpty() ){
+
+			opts.append( "V" ) ;
+			opts.append( m ) ;
+		}
+
+		m = this->arg( "L" ) ;
+
+		if( !m.isEmpty() ){
+
+			opts.append( "L" ) ;
+			opts.append( m ) ;
+		}
+
+		m = this->arg( "b" ) ;
+
+		if( !m.isEmpty() ){
+
+			opts.append( "b" ) ;
+			opts.append( m ) ;
+		}
+
+		m = this->arg( "--longnamemax" ) ;
+
+		if( !m.isEmpty() ){
+
+		       opts.append( "--longnamemax" ) ;
+		       opts.append( m ) ;
+		}
+
+		m = this->arg( "--scryptn" ) ;
+
+		if( !m.isEmpty() ){
+
+		      opts.append( "--scryptn" ) ;
+		      opts.append( m ) ;
+		}
+
+		opts.append( "--init=" + m_cryptFolder ) ;
+
+		return opts ;
+	}
+	const QString cppcryptfsctl() const
+	{
+		return m_cppcryptfsctl ;
+	}
+	const QString& mountPoint() const
+	{
+		return m_mountPoint ;
+	}
+	const QByteArray& password() const
+	{
+		return m_password ;
+	}
+	void setPassowrd( QByteArray p )
+	{
+		m_password = std::move( p ) ;
+	}
+private:
+	QString arg( const char * arg ) const
+	{
+		int j = m_args.size() ;
 
 		for( int i = 0 ; i < j ; i++ ){
 
-			if( args.at( i ) == arg ){
+			if( m_args.at( i ) == arg ){
 
 				if( i + 1 < j ){
 
-					return args.at( i + 1 ) ;
+					return m_args.at( i + 1 ) ;
 				}else{
 					return {} ;
 				}
@@ -131,6 +251,13 @@ private:
 
 		return {} ;
 	}
+
+	QStringList m_args ;
+	QString m_cryptFolder ;
+	QString m_mountPoint ;
+	QString m_configPath ;
+	QString m_cppcryptfsctl ;
+	QByteArray m_password ;
 };
 
 template< typename Function,typename Ctx >
@@ -236,15 +363,15 @@ static QString _deviceName( const context& ctx )
 	std::fill( mountPoint.begin(),mountPoint.end(),'\0' ) ;
 	std::fill( buffer.begin(),buffer.end(),'\0' ) ;
 
-	if( _is_driveLetter( ctx.mountPoint ) ){
+	if( _is_driveLetter( ctx.mountPoint() ) ){
 
-		ctx.mountPoint.toWCharArray( mountPoint.data() ) ;
+		ctx.mountPoint().toWCharArray( mountPoint.data() ) ;
 
 		auto s = QueryDosDeviceW( mountPoint.data(),buffer.data(),buffer.size() ) ;
 
 		return QString::fromWCharArray( buffer.data(),s ) ;
 	}else{
-		auto m = ctx.mountPoint + "\\" ;
+		auto m = ctx.mountPoint() + "\\" ;
 
 		m.toWCharArray( mountPoint.data() ) ;
 
@@ -274,11 +401,12 @@ static void _hang_until_unmounted( const context& ctx,const QString& id )
 	} ) ;
 }
 
-static void _msg( const result& r,const char * msg )
+static void _msg( const result& r,const QString& msg )
 {
-	std::cout << "status: " << msg << "\n" ;
-	std::cout << "std out: " + r.stdOut().trimmed().toStdString() << "\n" ;
-	std::cout << "std error: " + r.stdError().trimmed().toStdString() << std::endl ;
+	std::wcout << L"status: " << msg.toStdWString() << L"\n" ;
+	std::wcout << L"std out: " << r.stdOut().trimmed().toStdWString() << L"\n" ;
+	std::wcout << L"std error: " << r.stdError().trimmed().toStdWString() << L"\n" ;
+	std::wcout << std::endl ;
 }
 
 template< typename Then >
@@ -310,14 +438,7 @@ static void _read_password( Then then )
 
 static void _mount( const context& ctx,counter c = 3 )
 {
-	QStringList args{ "-p",ctx.password,"-d",ctx.mountPoint,"-m",ctx.cryptFolder,"-c",ctx.configPath } ;
-
-	if( ctx.readOnly ){
-
-		args.append( "-r" ) ;
-	}
-
-	_run( ctx.cppcryptfsctl,args,[ &ctx,c ]( const result& m ){
+	_run( ctx.cppcryptfsctl(),ctx.unlocking_opts(),[ &ctx,c ]( const result& m ){
 
 		if( m.success() ){
 
@@ -339,11 +460,15 @@ static void _mount( const context& ctx,counter c = 3 )
 
 static void _info( const context& ctx,counter c = 3 )
 {
-	_run( ctx.cppcryptfsctl,{ "-i",ctx.mountPoint },[ &ctx,c ]( const result& m ){
+	_run( ctx.cppcryptfsctl(),{ "-i",ctx.mountPoint() },[ &ctx,c ]( const result& m ){
 
 		if( m.success() ){
 
-			auto s = m.stdOut().split( '\n' ) ;
+			auto ss = m.stdOut() ;
+
+			ss.replace( "\r","" ) ;
+
+			auto s = ss.split( '\n' ) ;
 
 			for( int i = 0 ; i < s.size() ; i++ ){
 
@@ -361,10 +486,10 @@ static void _info( const context& ctx,counter c = 3 )
 					}
 				}
 
-				std::cout << e.constData() << "\n" ;
+				std::wcout << e.toStdWString() << "\n" ;
 			}
 
-			std::cout << std::endl ;
+			std::wcout << L"\n" ;
 		}else{
 			if( m.retry( c ) ){
 
@@ -378,22 +503,15 @@ static void _info( const context& ctx,counter c = 3 )
 
 static void _umount( const context& ctx,counter c = 3 )
 {
-	QStringList opts{ "-u",ctx.mountPoint } ;
-
-	if( ctx.quitCppcryptfs ){
-
-		opts.append( "--exit" ) ;
-	}
-
-	_run( ctx.cppcryptfsctl,opts,[ &ctx,c ]( const result& m ){
+	_run( ctx.cppcryptfsctl(),ctx.umount_opts(),[ &ctx,c ]( const result& m ){
 
 		if( m.success() ){
 
-			if( !_is_driveLetter( ctx.mountPoint ) ){
+			if( !_is_driveLetter( ctx.mountPoint() ) ){
 
 				QDir d ;
-				d.rmdir( ctx.mountPoint ) ;
-				d.mkdir( ctx.mountPoint ) ;
+				d.rmdir( ctx.mountPoint() ) ;
+				d.mkdir( ctx.mountPoint() ) ;
 			}
 
 			_msg( m,"Umount Success" ) ;
@@ -412,26 +530,7 @@ static void _umount( const context& ctx,counter c = 3 )
 
 static void _create( const context& ctx,counter c = 3 )
 {
-	QStringList opts ;
-
-	if( ctx.contains( "--siv" ) ){
-
-		opts.append( "--siv" ) ;
-	}
-
-	if( ctx.contains( "--plaintext" ) ){
-
-		opts.append( "--plaintext" ) ;
-	}
-
-	if( ctx.contains( "--reverse" ) ){
-
-		opts.append( "--reverse" ) ;
-	}
-
-	opts.append( "--init=" + ctx.cryptFolder ) ;
-
-	_run( ctx.cppcryptfsctl,opts,ctx.password,[ &ctx,c ]( const result& m ){
+	_run( ctx.cppcryptfsctl(),ctx.creating_opts(),ctx.password(),[ &ctx,c ]( const result& m ){
 
 		if( m.success() ){
 
@@ -455,7 +554,7 @@ static void _exec( context& ctx )
 
 		_read_password( [ &ctx ]( QByteArray password ){
 
-			ctx.password = std::move( password ) ;
+			ctx.setPassowrd( std::move( password ) ) ;
 
 			_mount( ctx ) ;
 		} ) ;
@@ -468,7 +567,7 @@ static void _exec( context& ctx )
 
 		_read_password( [ & ]( const QByteArray& password ){
 
-			ctx.password = password + "\n" + password ;
+			ctx.setPassowrd( password + "\n" + password ) ;
 
 			_create( ctx ) ;
 		} ) ;
@@ -479,7 +578,7 @@ static void _exec( context& ctx )
 
 	}else if( ctx.contains( "--deviceName" ) ){
 
-		std::cout << _deviceName( ctx ).toStdString() << std::endl ;
+		std::wcout << _deviceName( ctx ).toStdWString() << L"\n" ;
 
 		_quit( 0 ) ;
 
@@ -487,7 +586,7 @@ static void _exec( context& ctx )
 
 		_hang_until_unmounted( ctx,_deviceName( ctx ) ) ;
 	}else{
-		std::cout << "Unknown command" << std::endl ;
+		std::wcout << L"Unknown command" << L"\n" ;
 
 		_quit( 255 ) ;
 	}
