@@ -17,6 +17,8 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "flatpak.h"
+
 #include "utility.h"
 
 #include <iostream>
@@ -36,6 +38,7 @@
 #include <QTranslator>
 #include <QEventLoop>
 #include <QDebug>
+#include <QSysInfo>
 #include <QCoreApplication>
 #include <QApplication>
 #include <QByteArray>
@@ -45,6 +48,7 @@
 #include <QDir>
 #include <QTableWidget>
 #include <QMessageBox>
+#include <QDesktopServices>
 #include <QTableWidgetItem>
 #include <QProcessEnvironment>
 #include <QtNetwork/QLocalSocket>
@@ -72,7 +76,6 @@
 #include "siriPolkit.h"
 #include "settings.h"
 #include "version.h"
-#include "runinthread.h"
 
 #ifdef Q_OS_LINUX
 
@@ -310,20 +313,27 @@ utility::debug utility::debug::operator<<( const QString& e )
 	return utility::debug() ;
 }
 
+static bool _firstTime = true ;
+
 void utility::applicationStarted()
 {
-	utility::miscOptions::instance().doneStarting() ;
+	if( _firstTime ){
 
-	const auto& m = utility::miscOptions::instance() ;
+		_firstTime = false ;
 
-	const auto& e = m.getStartingLogs() ;
+		auto& m = utility::miscOptions::instance() ;
 
-	if( !e.isEmpty() ){
+		m.doneStarting() ;
 
-		QString a = "***********Start early logs************" ;
-		QString b = "\n\n***********End early logs*****************" ;
+		const auto& e = m.getStartingLogs() ;
 
-		utility::logger().enableDebug().showText( a + e + b ).showDebugWindow() ;
+		if( !e.isEmpty() ){
+
+			QString a = "***********Start early logs************" ;
+			QString b = "\n\n***********End early logs*****************" ;
+
+			utility::logger().enableDebug().showText( a + e + b ).showDebugWindow() ;
+		}
 	}
 }
 
@@ -429,7 +439,7 @@ void utility::initGlobals()
 
 	auto& m = utility::miscOptions::instance() ;
 
-	m.setCurrentThreadAsMain() ;
+	m.setCurrentThreadAsMain() ;	
 
 	m.setEnableDebug( settings::instance().showDebugWindowOnStartup() ) ;
 
@@ -510,22 +520,51 @@ void utility::openPath( const QString& path,const QString& opener,
 {
 	if( !path.isEmpty() ){
 
-		openPath( path,opener ).then( [ title,msg,obj ]( bool failed ){
+		if( utility::platformIsFlatPak() ){
 
-			if( utility::platformIsNOTWindows() ){
+			auto exe = "flatpak-spawn" ;
 
-				if( failed && obj ){
+			QStringList args{ "--host",opener,path } ;
 
-					DialogMsg( obj ).ShowUIOK( title,msg ) ;
-				}
+			utility::logger logger ;
+
+			logger.showText( exe,args ) ;
+
+			if( QProcess::startDetached( exe,args ) ){
+
+				logger.showText( ::Task::process::result( 0 ) ) ;
+			}else{
+				logger.showText( ::Task::process::result( 1 ) ) ;
 			}
-		} ) ;
+		}else{
+			auto& e = openPath( path,opener ) ;
+
+			e.then( [ title,msg,obj ]( bool failed ){
+
+				if( utility::platformIsNOTWindows() ){
+
+					if( failed && obj ){
+
+						DialogMsg( obj ).ShowUIOK( title,msg ) ;
+					}
+				}
+			} ) ;
+		}
 	}
 }
 
+static QString _version_string()
+{
+	QString s = VERSION_STRING ;
+
+	s.replace( ".git_tag","" ) ;
+
+	return s ;
+}
+
 static bool _help()
 {
-	utility::debug::cout() << VERSION_STRING << QObject::tr( "\n\
+	utility::debug::cout() << _version_string() << QObject::tr( "\n\
 options:\n\
 	-d   Path to where a volume to be auto unlocked/mounted is located.\n\
 	-m   Tool to use to open a default file manager(default tool is xdg-open).\n\
@@ -685,7 +724,7 @@ This program is distributed in the hope that it will be useful,\
 but WITHOUT ANY WARRANTY; without even the implied warranty of \
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \
 GNU General Public License for more details.\n\
-" ).arg( VERSION_STRING ) ;
+" ).arg( _version_string() ) ;
 
 	DialogMsg( parent,nullptr ).ShowUIInfo( QObject::tr( "about SiriKali" ),true,license ) ;
 }
@@ -874,18 +913,13 @@ bool utility::createFolder( const QString& m )
 	}
 }
 
-bool utility::removeFolder( const QString& e,int attempts )
+static bool _removeFolder( const QString& mountPath,int attempts )
 {
-	if( utility::isDriveLetter( e ) ){
-
-		return true ;
-	}
-
 	QDir dir ;
 
-	dir.rmdir( e ) ;
+	dir.rmdir( mountPath ) ;
 
-	if( utility::pathNotExists( e ) ){
+	if( utility::pathNotExists( mountPath ) ){
 
 		return true ;
 	}else{
@@ -893,9 +927,9 @@ bool utility::removeFolder( const QString& e,int attempts )
 
 			utility::waitForOneSecond() ;
 
-			dir.rmdir( e ) ;
+			dir.rmdir( mountPath ) ;
 
-			if( utility::pathNotExists( e ) ){
+			if( utility::pathNotExists( mountPath ) ){
 
 				return true ;
 			}
@@ -905,6 +939,47 @@ bool utility::removeFolder( const QString& e,int attempts )
 	}
 }
 
+bool utility::removeFolder( const QString& mountPath,int attempts )
+{
+	if( utility::platformIsFlatPak() ){
+
+		if( mountPath.startsWith( settings::instance().homePath() ) ){
+
+			return _removeFolder( mountPath,attempts ) ;
+		}else{
+			auto exe = "flatpak-spawn" ;
+
+			QStringList args{ "--host","rmdir",mountPath } ;
+
+			auto env = QProcessEnvironment::systemEnvironment() ;
+
+			utility::logger logger ;
+
+			logger.showText( exe,args ) ;
+
+			for( int i = 0 ; i < attempts ; i++ ){
+
+				auto mm = ::Task::process::run( exe,args,-1,{},env ).await() ;
+
+				logger.showText( mm ) ;
+
+				if( mm.success() ){
+
+					return true ;
+				}
+			}
+
+			return false ;
+		}
+
+	}else if( utility::isDriveLetter( mountPath ) ){
+
+		return true ;
+	}else{
+		return _removeFolder( mountPath,attempts ) ;
+	}
+}
+
 static bool _terminalEchoOff( struct termios * old,struct termios * current )
 {
 	if( tcgetattr( 1,old ) != 0 ){
@@ -990,7 +1065,8 @@ QByteArray utility::readPassword( bool addNewLine )
 
 const QProcessEnvironment& utility::systemEnvironment()
 {
-	static class sysEnv{
+	static class sysEnv
+	{
 	public:
 		sysEnv() : m_QProcessEnvironment( QProcessEnvironment::systemEnvironment() )
 		{
@@ -1139,7 +1215,7 @@ static void _setWindowsMountMountOptions( QWidget * obj,E e,QPushButton * s )
 	menu->addActions( actions ) ;
 
 	s->setMenu( menu ) ;
-	s->setIcon( QIcon( ":/harddrive.png" ) ) ;
+    s->setIcon( QIcon( ":/icons/harddrive.png" ) ) ;
 }
 
 void utility::setWindowsMountPointOptions( QWidget * obj,QTextEdit * e,QPushButton * s )
@@ -1152,11 +1228,6 @@ void utility::setWindowsMountPointOptions( QWidget * obj,QLineEdit * e,QPushButt
 	_setWindowsMountMountOptions( obj,e,s ) ;
 }
 
-void utility::runInUiThread( std::function< void() > function )
-{
-	runInThread::instance( utility::miscOptions::instance().getMainGUIThread(),std::move( function ) ) ;
-}
-
 void utility::waitForOneSecond()
 {
 	utility::wait( 1 ) ;
@@ -1475,7 +1546,11 @@ utility::logger& utility::logger::enableDebug()
 
 QString utility::SiriKaliVersion()
 {
-	return THIS_VERSION ;
+	QString s = THIS_VERSION ;
+
+	s.replace( ".git_tag","" ) ;
+
+	return s ;
 }
 
 #ifdef Q_OS_WIN
@@ -1604,3 +1679,99 @@ QStringList utility::splitPreserveQuotes( const QString& e )
 	return QProcess::splitCommand( e ) ;
 #endif
 }
+
+#if FLATPAK
+
+bool utility::platformIsFlatPak()
+{
+	return true ;
+}
+
+#else
+
+bool utility::platformIsFlatPak()
+{
+	return false ;
+}
+
+#endif
+
+bool utility::copyFile( const QString& s,const QString& d,bool setExePermssion )
+{
+	QFile src( s ) ;
+
+	if( src.open( QIODevice::ReadOnly ) ){
+
+		QFile dst( d ) ;
+
+		if( dst.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
+
+			std::array< char,1024 > buffer ;
+
+			while( true ){
+
+				auto m = src.read( buffer.data(),buffer.size() ) ;
+
+				if( m > 0 ){
+
+					dst.write( buffer.data(),m ) ;
+				}else{
+					if( src.size() == dst.size() ){
+
+						if( setExePermssion ){
+
+							auto s = dst.permissions() | QFileDevice::ExeOwner ;
+
+							dst.setPermissions( s ) ;
+						}
+
+						return true ;
+					}else{
+						dst.remove() ;
+
+						return false ;
+					}
+				}
+			}
+		}
+	}
+
+	return false ;
+}
+
+static QString _currentCpuArch()
+{
+#if QT_VERSION < QT_VERSION_CHECK( 5,4,0 )
+
+	return {} ;
+#else
+	return QSysInfo::currentCpuArchitecture() ;
+#endif
+}
+
+bool utility::archInUse( utility::arch m )
+{
+	auto e = _currentCpuArch() ;
+
+	if( m == utility::arch::x64 ){
+
+		return e == "x86_64";
+
+	}else if( m == utility::arch::x86 ){
+
+		return e == "i386" ;
+
+	}else if( m == utility::arch::aarch64 ){
+
+		return e == "arm64" ;
+	}else{
+		return false ;
+	}
+}
+
+QString utility::cleanPath( const QString& e )
+{
+	auto m = QDir::cleanPath( e ) ;
+
+	return QDir::toNativeSeparators( m ) ;
+}
